@@ -186,7 +186,7 @@ test_that("The calc_BCSMD() works appropriately for treatment reversal designs."
 })
 
 
-test_that("calc_BCSMD() returns same result as g_mlm() for Laski data.", {
+test_that("calc_BCSMD() returns same result as g_mlm() for Laski data with a simple model.", {
   
   data(Laski)
   
@@ -216,6 +216,14 @@ test_that("calc_BCSMD() returns same result as g_mlm() for Laski data.", {
   expect_equal(Laski_g1_mlm$SE_g_AB, Laski_calc_BCSMD_summary$`Std. Error`)
   expect_equal(Laski_g1_mlm$nu, Laski_calc_BCSMD_summary$`Degrees of freedom`)
   
+})
+
+
+test_that("calc_BCSMD() returns same result as g_mlm() for Laski data with a complex model.", {
+
+  skip_on_cran()
+  
+  data(Laski)
   
   # complex model
   default_AB <- default_times(design = "MBP",
@@ -259,14 +267,14 @@ test_that("calc_BCSMD() returns same result as g_mlm() for Laski data.", {
   
 })
 
-
-test_that("calc_BCSMD() returns the same result as g_mlm() for Bryant 2018 data.", {
+test_that("calc_BCSMD() returns the same result as g_mlm() for Bryant 2018 data with a simple model.", {
   
   data(Bryant2018)
   Bryant_RML1 <- lme(fixed = outcome ~ treatment,
                      random = ~ 1 | group/case,
                      correlation = corAR1(0.01, ~ session | group/case),
-                     data = Bryant2018)
+                     data = Bryant2018,
+                     na.action = na.omit)
   
   # simple model
   suppressWarnings(expect_error(g_REML(Bryant_RML1, p_const = c(0, 1), r_const = c(1, 0, 1, 1)))) # g_REML not available for 3-level data
@@ -294,8 +302,20 @@ test_that("calc_BCSMD() returns the same result as g_mlm() for Bryant 2018 data.
   
   expect_equal(CI_g(Bry_g1_mlm)[1], Bry_BCSMD_summary$`95% CI (lower)`)
   expect_equal(CI_g(Bry_g1_mlm)[2], Bry_BCSMD_summary$`95% CI (upper)`)
-  
 
+})
+
+test_that("calc_BCSMD() returns the same result as g_mlm() for Bryant 2018 data with a complex model.", {
+
+  skip_on_cran()
+  
+  data(Bryant2018)
+  Bryant_RML1 <- lme(fixed = outcome ~ treatment,
+                     random = ~ 1 | group/case,
+                     correlation = corAR1(0.01, ~ session | group/case),
+                     data = Bryant2018,
+                     na.action = na.omit)
+  
   # complex model
   default_AB <- default_times(design = "CMB",
                               cluster = group, case = case, phase = treatment, session = session, 
@@ -345,11 +365,11 @@ test_that("calc_BCSMD() returns the same result as g_mlm() for Bryant 2018 data.
   
 })
 
-
 test_that("The batch_calc_BCSMD() works for MBP design.", {
   
   # single calculator
   data("Laski")
+  skip_if_not_installed("dplyr", "1.1.0")
   
   # model 1: basic model without time trends
   Laski1_single <- 
@@ -403,7 +423,7 @@ test_that("The batch_calc_BCSMD() works for MBP design.", {
   res_AB <- 
     dat_MBP %>% 
     dplyr::group_by(studyID) %>%
-    dplyr::summarise(
+    dplyr::reframe(
       default_times(
         design = "MBP",
         case = case,
@@ -411,8 +431,7 @@ test_that("The batch_calc_BCSMD() works for MBP design.", {
         session = session,
         cluster = NULL,
         series = NULL
-      ),
-      .groups = 'drop'
+      )
     ) %>% 
     dplyr::mutate(variable = rep(c("range", "A", "B"), length(unique(dat_MBP$studyID)))) %>% 
     dplyr::rename(value = `default_times(...)`)
